[![DeepSource](https://deepsource.io/gh/freezerain/sensamag-utility.svg/?label=active+issues&show_trend=true&token=tqqs40FSee57xeO0zqak7Fs1)](https://deepsource.io/gh/freezerain/sensamag-utility/?ref=repository-badge)
[![DeepSource](https://deepsource.io/gh/freezerain/sensamag-utility.svg/?label=resolved+issues&show_trend=true&token=tqqs40FSee57xeO0zqak7Fs1)](https://deepsource.io/gh/freezerain/sensamag-utility/?ref=repository-badge)

This package is used to update Sensamag data base.